--[[
	Copyright © 2013 Samuel Guillaume
	This work is free. You can redistribute it and/or modify it under the
	terms of the Do What The Fuck You Want To Public License, Version 2,
	as published by Sam Hocevar. See http://www.wtfpl.net/ for more details.
--]]

--require 'lovedebug'

function love.load()
	love.graphics.setMode(800,600)
	love.graphics.setBackgroundColor(12,12,255,255)
	font = love.graphics.newFont("unispace.ttf",15)
	love.graphics.setFont(font)
	changed = false
	joystick = 1

	require 'xboxlove'
	controller = xboxlove.create(joystick)
	deadzone = 0
	if controller then 
		controller:setDeadzone("ALL",deadzone)
	end
end

function love.update(dt)
	if controller then
		controller:setJoystick(joystick)
		joystick = controller:getJoystick()
		if deadzone < 0 then deadzone = 0
		elseif deadzone > 1 then deadzone = 1 end
		controller:setDeadzone("ALL",deadzone)
		controller:update(dt)
	end
end

function love.keypressed(key,value)
	if key == "escape" then love.event.push("quit")
	elseif key == "right" then deadzone = deadzone + 0.05 ; changed = true
	elseif key == "left" then deadzone = deadzone - 0.05 ; changed = true
	elseif key == "up" then joystick = joystick + 1 ; changed = true
	elseif key == "down" then joystick = joystick - 1 ; changed = true
	end
end

function round(num, idp)
  return tonumber(string.format("%." .. (idp or 0) .. "f", num))
end

function love.draw()
	if not controller then
		love.graphics.print("There is no xbox controller plug-in",1,1)
		return false
	end
	love.graphics.setColor(255,255,255,255)
	love.graphics.print(love.joystick.getName(joystick),0,0)
	if not changed then love.graphics.print("Use the arrows to change the joystick and deadzone",0,17) end

	love.graphics.print("Joystick : " .. joystick,love.graphics.getWidth()-font:getWidth("Joystick : " .. joystick),0)
		--Axes
	love.graphics.setColor(255,255,255,255)
	love.graphics.push()
	love.graphics.translate(200,490)
	love.graphics.print("Left Stick : " .. round(controller.Axes.LeftX,3) .. "X - ".. round(controller.Axes.LeftY,3) .. "Y",-100,-120)
	love.graphics.circle("line",0,0,100)
	if controller.Axes.LeftAngle then
		love.graphics.rotate(controller.Axes.LeftAngle)
		if math.abs(controller.Axes.LeftAngle) <= math.pi/2 then
			love.graphics.print(round(controller.Axes.LeftAngle*(180/math.pi)) .. " deg",10,10)
		else
			love.graphics.rotate(math.pi)
			local translateX = font:getWidth(round(controller.Axes.LeftAngle*(180/math.pi)) .. " deg")+20
			local translateY = 35
			love.graphics.translate(-translateX,-translateY)
			love.graphics.print(round(controller.Axes.LeftAngle*(180/math.pi)) .. " deg",10,10)
			love.graphics.translate(translateX,translateY)
			love.graphics.rotate(math.pi)
		end 
		love.graphics.setColor(255,0,0,255)
		love.graphics.line(0,0,100,0)
	else
		love.graphics.print("None",10,10)
		love.graphics.point(0,0)
	end
	love.graphics.pop()

	love.graphics.setColor(255,255,255,255)
	love.graphics.push()
	love.graphics.translate(600,490)
	love.graphics.print("Right Stick : " .. round(controller.Axes.RightX,3) .. "X - ".. round(controller.Axes.RightY,3) .. "Y",-100,-120)
	love.graphics.circle("line",0,0,100)
	if controller.Axes.RightAngle then 
		love.graphics.rotate(controller.Axes.RightAngle)
		if math.abs(controller.Axes.RightAngle) <= math.pi/2 then
			love.graphics.print(round(controller.Axes.RightAngle*(180/math.pi)) .. " deg",10,10)
		else
			love.graphics.rotate(math.pi)
			local translateX = font:getWidth(round(controller.Axes.RightAngle*(180/math.pi)) .. " deg")+20
			local translateY = 35
			love.graphics.translate(-translateX,-translateY)
			love.graphics.print(round(controller.Axes.RightAngle*(180/math.pi)) .. " deg",10,10)
			love.graphics.translate(translateX,translateY)
			love.graphics.rotate(math.pi)
		end 
		love.graphics.setColor(255,0,0,255)
		love.graphics.line(0,0,100,0)
	else
		love.graphics.print("None",10,10)
		love.graphics.point(0,0)
	end
	love.graphics.pop()

	love.graphics.setColor(255,255,255,255)
	love.graphics.print("<- Triggers ->",love.graphics.getWidth()/2 -font:getWidth("<- Triggers ->")/2,500)
	love.graphics.print(round(controller.Axes.Triggers,3),love.graphics.getWidth()/2 -font:getWidth(round(controller.Axes.Triggers,3))/2,520)
	love.graphics.print("Deadzone : " .. deadzone,love.graphics.getWidth()/2-font:getWidth("Deadzone : " .. deadzone)/2,400)
	local x,y = love.graphics.getWidth()/2 -font:getWidth("Triggers"),love.graphics.getHeight()+1
	love.graphics.setColor(255,0,0,255)
	love.graphics.line(x,y,x,y-(controller.Axes.LeftTrigger*200))
	x = love.graphics.getWidth()/2 +font:getWidth("Triggers")
	love.graphics.line(x,y,x,y-(controller.Axes.RightTrigger*200))

		
		--Dpad
	love.graphics.setColor(255,255,255,255)
	love.graphics.push()
	love.graphics.translate(80,50)
	love.graphics.print("Dpad : " .. controller.Dpad.Direction,-7,10)
	if controller.Dpad.Centered then love.graphics.setColor(255,0,0,255)
	else love.graphics.setColor(255,255,255,255) end
	love.graphics.rectangle("fill",80,80,80,80)
	love.graphics.setColor(0,0,0,255)
	love.graphics.rectangle("line",80,80,80,80)
	if controller.Dpad.Up then love.graphics.setColor(255,0,0,255)
	else love.graphics.setColor(255,255,255,255) end
	love.graphics.rectangle("fill",80,0,80,80)
	love.graphics.setColor(0,0,0,255)
	love.graphics.rectangle("line",80,0,80,80)
	if controller.Dpad.Down then love.graphics.setColor(255,0,0,255)
	else love.graphics.setColor(255,255,255,255) end
	love.graphics.rectangle("fill",80,80*2,80,80)
	love.graphics.setColor(0,0,0,255)
	love.graphics.rectangle("line",80,80*2,80,80)
	if controller.Dpad.Left then love.graphics.setColor(255,0,0,255)
	else love.graphics.setColor(255,255,255,255) end
	love.graphics.rectangle("fill",0,80,80,80)
	love.graphics.setColor(0,0,0,255)
	love.graphics.rectangle("line",0,80,80,80)
	if controller.Dpad.Right then love.graphics.setColor(255,0,0,255)
	else love.graphics.setColor(255,255,255,255) end
	love.graphics.rectangle("fill",80*2,80,80,80)
	love.graphics.setColor(0,0,0,255)
	love.graphics.rectangle("line",80*2,80,80,80)
	love.graphics.pop()

		--Buttons
	love.graphics.push()
	love.graphics.setColor(255,255,255,255)
	love.graphics.translate(575,60)
	love.graphics.print("Buttons : ",-font:getWidth("Buttons : ")-20,0)
	local i = 0
	for k,v in pairs(controller.Buttons) do
		 if v then love.graphics.setColor(255,0,0,255)
		else love.graphics.setColor(255,255,255,255) end
		love.graphics.print(k,0,i*20)
		i = i+1
	end
	love.graphics.pop()
end


